# Changelog

## 6.1.0 (2025-02-05)

Full Changelog: [v6.0.1...v6.1.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.0.1...v6.1.0)

### Features

* **api:** update via SDK Studio ([#15](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/15)) ([d71f24c](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/d71f24cabfea30410d02bc1266555c887d2f6427))

## 6.0.1 (2025-02-05)

Full Changelog: [v0.1.0-alpha.1...v6.0.1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v0.1.0-alpha.1...v6.0.1)

### Features

* **api:** update via SDK Studio ([#12](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/12)) ([2bc88a9](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/2bc88a97cf124d86dd2c1a397a6d0865441c884a))

## 0.1.0-alpha.1 (2025-02-04)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/6)) ([2f9923b](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/2f9923bd9989785ee26457bf4d98644732ebd0f1))
* **api:** update via SDK Studio ([#9](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/9)) ([8380155](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/83801559f49536dba48d5bdefe312deef6ad9342))


### Chores

* go live ([#1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/1)) ([839a103](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/839a10374ebfdcc038aeb4f98e66f9ed94f2de18))
* sync repo ([f502699](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/f502699a4803d8542b3681580a76500608b87900))
* update SDK settings ([#3](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/3)) ([66cb8ec](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/66cb8ec4118e474cb247ac45272396e5eff8bca3))
